@@ -9,7 +9,6 @@
  *
  */
 
-#include "day_render.h"
 #include <gpe/event-db.h>
 #include <sys/types.h>
 #include <stdio.h>
@@ -23,6 +22,9 @@
 #include <glib.h>
 #include <gpe/pixmaps.h>
 
+#include "day_render.h"
+#include "day_view.h"
+
 #define event_ends(event) ((event)->start + (event)->duration)
 
 
@@ -522,10 +524,6 @@ day_render_set_event_rectangles (struct day_render *dr)
 
   gtk_widget_add_events (GTK_WIDGET (dr->widget),
 			 GDK_BUTTON_PRESS_MASK | GDK_BUTTON_RELEASE_MASK);
-
-
-
-
 }
 
 void
@@ -600,7 +598,7 @@ day_render_new (GtkWidget * widget,
   dr->dy = (page->height) / (dr->rows + 2);
   dr->normal_gc = app_gc;
   dr->ol_gc = overl_gc;
-  dr->offset.x = page->width / page->time_col_ratio;
+  dr->offset.x = page->time_width;
   dr->offset.y = 0;
 
   pbuf = gpe_find_icon ("bell");
@@ -613,7 +611,7 @@ day_render_new (GtkWidget * widget,
   day_render_set_event_rectangles (dr);
 
   g_signal_connect (G_OBJECT (dr->widget), "button-press-event",
-		    G_CALLBACK (button_press), dr);
+		    G_CALLBACK (day_view_button_press), dr);
   return dr;
 
 }
@@ -626,16 +624,17 @@ day_render_delete (struct day_render *dr)
   if (dr != NULL)
     {
       g_signal_handlers_disconnect_by_func (G_OBJECT (dr->widget),
-					    button_press, dr);
+					    day_view_button_press, dr);
       GSList *iter;
       iter = dr->event_rectangles;
       while (iter)
-	{
-	  event_rect_delete (iter->data);
-	  iter = iter->next;
-	}
+       {
+         event_rect_delete (iter->data);
+         iter = iter->next;
+       }
 
       g_slist_free (dr->event_rectangles);
+      g_slist_free (dr->events);
       g_free (dr->capt);
       g_free (dr);
     }
@@ -770,9 +769,8 @@ day_render_event_show (struct day_render *dr, event_t event, GdkGC * gc)
 
   if (!event_starts_today (dr, event))
     {
-      length =
-	(guint) (((float) event->start + (float) event->duration -
-		  (float) dr->date) / 3600.0 * (float) dr->dx);
+      length = (guint) (((float) event->start + (float) event->duration -
+               (float) dr->date) / 3600.0 * (float) dr->dx);
     }
   else
     {
@@ -798,80 +796,32 @@ day_render_event_show (struct day_render *dr, event_t event, GdkGC * gc)
       reminder = length - (dr->page->width - (start->point).x);
 
       while ((reminder > dr->page->width) && reminder > 0)
-	{
-	  gdk_draw_rectangle (dr->draw, gc, TRUE, offset.x,
-			      (start->point).y + offset.y + dr->gap 
-		            + (i - start->row_num - 1) * dr->dy, 
-		          dr->page->width, dr->dy - dr->gap);
-	  reminder -= dr->page->width;
-
-	  ++i;
-	  if (i > dr->rows)
-	    {
-	      break;
-	    }
-	}
+        {
+          gdk_draw_rectangle (dr->draw, gc, TRUE, offset.x,
+                      (start->point).y + offset.y + dr->gap 
+                        + (i - start->row_num - 1) * dr->dy, 
+                      dr->page->width, dr->dy - dr->gap);
+          reminder -= dr->page->width;
+    
+          ++i;
+          if (i > dr->rows)
+            {
+              break;
+            }
+        }
       if (i <= dr->rows)
-	{
-	  gdk_draw_rectangle (dr->draw, gc, TRUE, offset.x,
-			      (start->point).y + offset.y + dr->gap + (i -
-								       start->
-								       row_num
-								       -
-								       1) *
-			      dr->dy, reminder, dr->dy - dr->gap);
-	}
+        {
+          gdk_draw_rectangle (dr->draw, gc, TRUE, offset.x,
+                      (start->point).y + offset.y + dr->gap + (i -
+                                           start->
+                                           row_num
+                                           -
+                                           1) *
+                      dr->dy, reminder, dr->dy - dr->gap);
+        }
     }
 }
 
-#if 0
-
-/* Renders day caption */
-void
-day_render_caption_show (struct day_render *dr)
-{
-  caption_show (dr->capt);
-}
-
-/* Show day with events and stuff. */
-void
-day_render_events_show (struct day_render *dr, GSList * events, GdkGC * gc)
-{
-  GSList *iter;
-
-  for (iter = events; iter; iter = iter->next)
-    {
-      day_render_event_show (dr, iter->data, gc);
-
-    }
-}
-
-/* Renders day element... */
-void
-day_render_show (struct day_render *dr)
-{
-  GSList *ol_list, *iter;
-  day_render_caption_show (dr);
-  /* shows events if any... */
-  if (dr->events != NULL)
-    day_render_events_show (dr, dr->events, dr->normal_gc);
-
-  /* shows overlapping areas if any... */
-  ol_list = day_render_find_overlapping (dr->events);
-  if (ol_list != NULL)
-    {
-      day_render_events_show (dr, ol_list, dr->ol_gc);
-    }
-
-  iter = ol_list;
-  while (iter)
-    {
-      g_free (iter->data);
-      iter = iter->next;
-    }
-
-}
-#endif
 GdkGC *
 pen_new (GtkWidget * widget, guint red, guint green, guint blue)
 {
